@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gestures-extension.c,v 1.6.2.1 2004/02/21 23:02:05 chpe Exp $
+ *  $Id: ephy-gestures-extension.c,v 1.10 2004/08/06 02:02:08 adamh Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -316,17 +316,17 @@ dom_mouse_down_cb (EphyEmbed *embed,
             !(context & EMBED_CONTEXT_INPUT))
 	{
 		EphyGesture *gesture;
-		EphyWindow *window;
+		GtkWidget *toplevel;
 		EphyTab *tab;
 		guint x, y;
 
 		tab = ephy_tab_for_embed (embed);
 		g_return_if_fail (EPHY_IS_TAB (tab));
 
-		window = ephy_tab_get_window (tab);
-		g_return_if_fail (EPHY_IS_WINDOW (window));
+		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (tab));
+		g_return_if_fail (toplevel != NULL);
 
-		gesture = ephy_gesture_new (GTK_WIDGET (window), event);
+		gesture = ephy_gesture_new (toplevel, event);
 
 		g_signal_connect (gesture, "gesture-performed",
 				  G_CALLBACK (gesture_performed_cb),
@@ -342,12 +342,15 @@ dom_mouse_down_cb (EphyEmbed *embed,
 
 static void
 tab_added_cb (GtkWidget *notebook,
-	      EphyEmbed *embed,
+	      EphyTab *tab,
 	      EphyGesturesExtension *extension)
 {
-	EphyTab *tab;
+	EphyEmbed *embed;
 
-	tab = ephy_tab_for_embed (embed);
+	g_return_if_fail (EPHY_IS_TAB (tab));
+
+	embed = ephy_tab_get_embed (tab);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	g_signal_connect (embed, "ge_dom_mouse_down",
 			  G_CALLBACK (dom_mouse_down_cb), extension);
@@ -355,12 +358,15 @@ tab_added_cb (GtkWidget *notebook,
 
 static void
 tab_removed_cb (GtkWidget *notebook,
-		EphyEmbed *embed,
+		EphyTab *tab,
 		EphyGesturesExtension *extension)
 {
-	EphyTab *tab;
+	EphyEmbed *embed;
 
-	tab = ephy_tab_for_embed (embed);
+	g_return_if_fail (EPHY_IS_TAB (tab));
+
+	embed = ephy_tab_get_embed (tab);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	g_signal_handlers_disconnect_by_func
 		(embed, G_CALLBACK (dom_mouse_down_cb), extension);
@@ -371,6 +377,17 @@ impl_attach_window (EphyExtension *extension,
 		    EphyWindow *window)
 {
 	GtkWidget *notebook;
+	GList *tabs, *l;
+
+	tabs = ephy_window_get_tabs (window);
+
+	for (l = tabs; l != NULL; l = g_list_next (l))
+	{
+		tab_added_cb (NULL, l->data,
+			      (EphyGesturesExtension *) extension);
+	}
+
+	g_list_free (tabs);
 
 	notebook = ephy_window_get_notebook (window);
 
@@ -385,6 +402,7 @@ impl_detach_window (EphyExtension *extension,
 		    EphyWindow *window)
 {
 	GtkWidget *notebook;
+	GList *tabs, *l;
 
 	notebook = ephy_window_get_notebook (window);
 
@@ -392,6 +410,16 @@ impl_detach_window (EphyExtension *extension,
 		(notebook, G_CALLBACK (tab_added_cb), extension);
 	g_signal_handlers_disconnect_by_func
 		(notebook, G_CALLBACK (tab_removed_cb), extension);
+
+	tabs = ephy_window_get_tabs (window);
+
+	for (l = tabs; l != NULL; l = g_list_next (l))
+	{
+		tab_removed_cb (NULL, l->data,
+				(EphyGesturesExtension *) extension);
+	}
+
+	g_list_free (tabs);
 }
 
 static void
